class ApplicationController < ActionController::Base

  helper_method :is_admin?

  protect_from_forgery

  EARTH_RADIUS = 3963.19
  RADIAN_PER_DEGREE = Math::PI / 180.0

  def haversine_distance(lat1, lng1, lat2, lng2)
    return 0 if lat1.nil? or lat2.nil? or lng1.nil? or lng2.nil?
    
    distance_lat = (lat2-lat1)
    distance_lng = (lng2-lng1)

    distlat_radians = distance_lat * RADIAN_PER_DEGREE
    distlng_radians = distance_lng * RADIAN_PER_DEGREE

    lat1_rad = lat1 * RADIAN_PER_DEGREE
    lon1_rad = lng1 * RADIAN_PER_DEGREE

    lat2_rad = lat2 * RADIAN_PER_DEGREE
    lon2_rad = lng2 * RADIAN_PER_DEGREE


    a = Math.sin(distlat_radians/2)**2 + Math.cos(lat1_rad) * Math.cos(lat2_rad) * Math.sin(distlng_radians/2) ** 2
    c = 2 * Math.atan2(Math.sqrt(a), Math.sqrt(1-a))
    EARTH_RADIUS * c  
  end


  def is_admin?
    unless current_user.admin?
      flash[:error] = "Voce nao tem acesso a essa pagina"
      redirect_to "/"
      false
    end
  end

end
