class Issue < ActiveRecord::Base
  attr_accessible :user_id, :title, :address, :latitude, :longitude, 
	:problem_nature_id, :issue_status_id, :description, :comments_attributes, :pictures_attributes

  attr_accessor :number_followers
  attr_accessor :number_comments
  attr_accessor :owner_avatar
  attr_accessor :user_name

  belongs_to :user
  has_many :followed_by_users,  :class_name => "User", :through => :follow_issue
  has_many :comments
  has_many :pictures
  has_one :problem_nature

  validates :title, :address, :issue_status_id, :problem_nature_id, :presence => true

  scope :find_by_problem_nature, lambda {|problem_nature_id| {:conditions => {:problem_nature_id => problem_nature_id}}}
  scope :find_by_status, lambda {|issue_status_id| {:conditions => {:issue_status_id => issue_status_id}}}

  def as_json(resume = false)
    if resume
      {
        :id => id,
        :user_id => user_id,
        :user_name => user_name,
        :title => title,
        :owner_avatar => owner_avatar
      }
    else
      {
        :id => id,
        :user_id => user_id,
        :user_name => user_name,
        :title => title,
        :address => address, 
        :description => description,
        :latitude => latitude, 
        :longitude => longitude,
        :owner_avatar => owner_avatar,
        :pictures => pictures,
        :comments => comments
      }
    end
  end
  accepts_nested_attributes_for :comments, :allow_destroy => true
  accepts_nested_attributes_for :pictures, :allow_destroy => true
end
